<?php

namespace EventPortal\Domain\Admin\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Concerns\HasTeams;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\Table\Concerns\HasTable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;
use Spatie\Permission\Traits\HasRoles;

class Admin extends Model implements AuditableInterface
{
    use AddToCasts, AddToFillable, HasTeams, HasRoles, HasTable, Auditable;

    protected $guard_name = 'web';

    const KEY = 'admin';

    /** @var array<string> */
    public $with = [
        'user',
    ];

    /** @var array<string> */
    protected $fillable = [
        'breaks_if_you_dont_have_this',
    ];

    public function user(): BelongsTo
    {
        return $this->belongsTo(config('auth.providers.users.model'), 'user_id');
    }

    public function getRoleAttribute(): ?Role
    {
        return $this->roles->first();
    }

    public function roleAsOption(): ?Option
    {
        if ($this->role === null) {
            return null;
        }

        return Option::make(optional($this->role)->label)->value(optional($this->role)->id);
    }

    public function getFullNameAttribute(): string
    {
        return $this->user->full_name;
    }
}
