<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Agenda\Actions\CreateDefaultAgenda;
use EventPortal\Domain\Agenda\Actions\DeleteAgenda;
use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Requests\StoreAgendaRequest;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Http\Controllers\Controller;
use Facades\EventPortal\Domain\Agenda\Agendas;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Arr;
use Inertia\Inertia;
use Inertia\Response;

class AgendaController extends Controller
{
    public function index(Event $event): Response
    {
        return Inertia::render('Agenda/Index', [
            'agendas' => Agendas::forEvent($event),
            'event' => $event->id,
        ]);
    }

    public function store(
        StoreAgendaRequest $request,
        Event $event,
        CreateDefaultAgenda $createDefaultAgenda
    ): RedirectResponse {
        $createDefaultAgenda->execute($event, Arr::get($request->only('dates'), 'dates'));

        return redirect()->route('admin.agenda.index', ['event' => $event]);
    }

    public function destroy(Event $event, Agenda $agenda, DeleteAgenda $deleteAgenda): RedirectResponse
    {
        $deleteAgenda->execute($agenda);

        return redirect()->route('admin.agenda.index', ['event' => $event]);
    }
}
