<?php

namespace EventPortal\Tests\Feature\Admin\Permission;

use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class RoleStoreTest extends TestCase
{
    use RefreshDatabase;

    /** @test */
    public function can_create_roles()
    {
        $user = factory(User::class)->create();

        $this->actingAs($user)
            ->post(route('admin.role.store'), [
                'name' => 'My role name',
            ]);

        $this->assertCount(1, Role::all());
        $role = Role::all()->first();

        $this->assertEquals('My role name', $role->label);
        $this->assertEquals('my-role-name', $role->name);
        $this->assertEquals('web', $role->guard_name);
    }

    /** @test */
    public function must_have_name()
    {
        $user = factory(User::class)->create();

        $response = $this->actingAs($user)
            ->post(route('admin.role.store'));

        $this->assertCount(0, Role::all());
        $response->assertSessionHasErrors(['name' => 'The name field is required.']);
    }

    /** @test */
    public function must_be_unique()
    {
        $user = factory(User::class)->create();

        factory(Role::class)->create([
            'label' => 'My role name',
            'name' => 'my-role-name',
        ]);

        $response = $this->actingAs($user)
            ->post(route('admin.role.store'), [
                'name' => 'My role name',
            ]);

        $this->assertCount(1, Role::all());
        $response->assertSessionHasErrors(['name' => 'This user type already exists.']);
    }

    /** @test */
    public function name_must_be_alpha()
    {
        $user = factory(User::class)->create();

        $response = $this->actingAs($user)
            ->post(route('admin.role.store'), [
                'name' => 1234,
            ]);

        $this->assertCount(0, Role::all());
        $response->assertSessionHasErrors(['name' => 'The name may only contain letters.']);
    }
}
