<?php

namespace EventPortal\Tests;

use DMS\PHPUnitExtensions\ArraySubset\ArraySubsetAsserts;
use EventPortal\Concerns\LoadTablesAndForms;
use EventPortal\Domain\User\Models\User;
use EventPortal\Providers\EventPortalServiceProvider;
use EventPortal\Tests\Support\Assertions\CollectionAssertions;
use EventPortal\Tests\Support\Assertions\PropAssertions;
use EventPortal\Tests\Support\Traits\InteractsWithAgendas;
use EventPortal\Tests\Support\Traits\InteractsWithAdminAuthentication;
use EventPortal\Tests\Support\Traits\InteractsWithEventDelegates;
use EventPortal\Tests\Support\Traits\InteractsWithEvents;
use EventPortal\Tests\Support\Traits\InteractsWithModels;
use EventPortal\Tests\Support\Traits\InteractsWithSessions;
use Illuminate\Support\Collection;
use Illuminate\Testing\TestResponse;

class TestCase extends \Orchestra\Testbench\TestCase
{
    use ArraySubsetAsserts,
        InteractsWithModels,
        InteractsWithEvents,
        InteractsWithAgendas,
        InteractsWithSessions,
        InteractsWithEventDelegates,
        InteractsWithAdminAuthentication,
        LoadTablesAndForms;

    public function setUp(): void
    {
        parent::setUp();

        $this->setupDatabase();

        $this->app->booted(function (): void {
            $this->loadForms();
            $this->loadTables();
        });

        TestResponse::mixin(new PropAssertions);
        Collection::mixin(new CollectionAssertions);
    }

    protected function getEnvironmentSetUp($app): void
    {
        $permissions = require './config/permission.php';
        $stateMachine = require './config/state-machine.php';

        $app->config->set('permission', $permissions);
        $app->config->set('state-machine', $stateMachine);
        $app->config->set('auth.providers.users.model', User::class);
    }

    protected function getPackageProviders($app): array
    {
        return [EventPortalServiceProvider::class];
    }

    private function setupDatabase(): void
    {
        $this->loadMigrationsFrom(base_path('/database/migrations'));

        include_once 'vendor/iben12/laravel-statable/database/migrations/create_state_history_table.php.stub';

        (new \CreateStateHistoryTable())->up();
    }
}
